@@ -498,7 +498,7 @@ def delete_ftp(file_path, ftp):
     '''
     success = False
     if exists_ftp(file_path, ftp):
-        print(f"{file_path} exists.")
+        # print(f"{file_path} exists.")
         try:
             ftp.rmtree(file_path)
             success = True
